@@ -16,6 +16,8 @@ class application(object):
         status = '200 OK'
         output = []
         output.append('<html><body>')
+        output.append('<p>SCRIPT_NAME: %s</p>' % repr(environ['SCRIPT_NAME']))
+        output.append('<p>PATH_INFO: %s</p>' % repr(environ['PATH_INFO']))
         if key is None:
             output.append('<p>Not any key is inputted yet.</p>')
         elif not session.has_key('pickey.displayed_key'):
@@ -26,7 +28,7 @@ class application(object):
             output.append('<p>Key Check failed: %s != %s</p>' %\
                               (repr(key),
                                repr(session['pickey.displayed_key'])))
-        output.append('<p>The Key is <img src="pickey"/></p>')
+        output.append('<p>The Key is <img src="pickey.png"/></p>')
         output.append('<form><input name="key"/><input type="submit"/></form>')
         output.append('</body></html>')
         output = string.join(output, '\n')
